@@ -36,27 +36,18 @@ pcr.tune <- function(y, x, M = 10, maxk = 50, mat = NULL, ncores = 1, graph = TR
 
       ytest <- y[mat[, vim] ]  ## test set dependent vars
       ytrain <- y[-mat[, vim] ]   ## train set dependent vars
-      xtrain <- x[-mat[, vim], ]   ## train set independent vars
+      xtrain <- x[-mat[, vim], , drop = FALSE]   ## train set independent vars
       xtest <- x[mat[, vim], , drop = FALSE]  ## test set independent vars
-      my <- mean(ytrain)
-      ytrain <- ytrain - my  ## standardize the dependent variable
-      m <- Rfast::colmeans(xtrain)
-      n <- dim(xtrain)[1]
-      s <- Rfast::colVars(xtrain, suma = n * m, std = TRUE)
-      xtrain <- t(xtrain) - m
-      xtrain <- xtrain/s
-      xtrain <- t(xtrain)
-      vec <- prcomp(xtrain, center = FALSE)$rotation
-      z <- xtrain %*% vec  ## PCA scores
-      znew <- t(xtest) - m
-      znew <- t( znew / s )
+      mod <- prcomp(xtrain, center = FALSE)
+      vec <- mod$rotation
+      z <- mod$x  ## PCA scores
       znew <- xtest %*% vec ## standardize the xnew values
       zzk <- crossprod(z)
       cy <- crossprod( z, ytrain )
       for ( j in 1:maxk ) {
         zzkj <- zzk[1:j, 1:j]
         be <- solve( zzkj, cy[1:j] )  ## (zzkj * zzkj^T )^(-1) * (z[1:j]^T * y)
-        est <- my + as.vector( znew[, 1:j, drop = FALSE] %*% be )  ## predicted values for PCA model
+        est <- as.vector( znew[, 1:j, drop = FALSE] %*% be )  ## predicted values for PCA model
         msp[vim, j] <- sum( (ytest - est)^2 ) / rmat
       }
     }
@@ -74,27 +65,18 @@ pcr.tune <- function(y, x, M = 10, maxk = 50, mat = NULL, ncores = 1, graph = TR
                             .export = c("colVars", "colmeans") ) %dopar% {
       ytest <-  y[mat[, vim] ]  ## test set dependent vars
       ytrain <- y[-mat[, vim] ]   ## train set dependent vars
-      xtrain <- x[-mat[, vim], ]   ## train set independent vars
-      xtest <-  x[mat[, vim], , drop = FALSE]  ## test set independent vars
-      my <- mean(ytrain)
-      ytrain <- ytrain - my  ## standardize the dependent variable
-      m <- Rfast::colmeans(xtrain)
-      n <- dim(xtrain)[1]
-      s <- Rfast::colVars(xtrain, suma = n * m, std = TRUE)
-      xtrain <- t(xtrain) - m
-      xtrain <- xtrain/s
-      xtrain <- t(xtrain)
-      vec <- prcomp(xtrain, center = FALSE)$rotation
-      z <- xtrain %*% vec  ## PCA scores
-      znew <- t(xtrain) - m
-      znew <- t( znew / s )
+      xtrain <- x[-mat[, vim], , drop = FALSE]   ## train set independent vars
+      xtest <- x[mat[, vim], , drop = FALSE]  ## test set independent vars
+      mod <- prcomp(xtrain, center = FALSE)
+      vec <- mod$rotation
+      z <- mod$x  ## PCA scores
       znew <- xtest %*% vec ## standardize the xnew values
       zzk <- crossprod(z)
       cy <- crossprod( z, ytrain )
       for ( j in 1:maxk ) {
         zzkj <- zzk[1:j, 1:j]
         be <- solve( zzkj, cy[1:j] )  ## (zzkj * zzkj^T )^(-1) * (z[1:j]^T * y)
-        est <- my + as.vector( znew %*% be )  ## predicted values for PCA model
+        est <- as.vector( znew %*% be )  ## predicted values for PCA model
         er[j] <- sum( (ytest - est)^2 ) / rmat
       }
       return(er)
@@ -105,7 +87,7 @@ pcr.tune <- function(y, x, M = 10, maxk = 50, mat = NULL, ncores = 1, graph = TR
   }
 
   mspe <- Rfast::colmeans(msp)
-  if ( graph )  plot(1:maxk, mspe, xlab = "Number of principal components", ylab = "MSPE", type = "b")
+  if ( graph )  plot(1:maxk, mspe, xlab = "Number of principal components", ylab = "MSPE", type = "b", cex.lab = 1.3)
   names(mspe) <- paste("PC", 1:maxk, sep = " ")
   performance <- min(mspe)
   names(performance) <- "MSPE"
